==> primefaces-11.0.0-RC1.jar: META-INF/resources/primefaces/locales/locale-lv.js <==
/** Latvian */
PrimeFaces.locales['lv'] = {
    closeText: 'Aizvērt',
    prevText: 'Iepriekšējais',
    nextText: 'Nākošais',
    monthNames: ['Janvāris', 'Februāris', 'Marts', 'Aprīlis', 'Maijs', 'Jūnijs', 'Jūlijs', 'Augusts', 'Septembris', 'Oktobris', 'Novembris', 'Decembris'],
    monthNamesShort: ['Jan', 'Feb', 'Mar', 'Apr', 'Mai', 'Jūn', 'Jūl', 'Aug', 'Sep', 'Okt', 'Nov', 'Dec'],
    dayNames: ['Svētdiena', 'Pirmdiena', 'Otrdiena', 'Trešdiena', 'Ceturtdiena', 'Piektdiena', 'Sestdiena'],
    dayNamesShort: ['Svē', 'Pirm', 'Otr', 'Tre', 'Cet', 'Pie', 'Ses'],
    dayNamesMin: ['Sv', 'P', 'O', 'T ', 'C', 'P ', 'S'],
    weekHeader: 'Nedēļa',
    firstDay: 1,
    isRTL: false,
    showMonthAfterYear: false,
    yearSuffix: '',
    timeOnlyTitle: 'Tikai laiks',
    timeText: 'Laiks',
    hourText: 'Stunda',
    minuteText: 'Minūte',
    secondText: 'Sekunde',
    millisecondText: 'Millisekunde',
    currentText: 'Šodiena',
    ampm: false,
    month: 'Mēnesis',
    week: 'Nedēļa',
    day: 'Diena',
    allDayText: 'Visa Diena',
    moreLinkText: 'Vairāk...',
    noEventsText: 'Nav notikumu',
    today: 'Šodiena',
    clear: 'Notīrīt',
    aria: {
        'paginator.PAGE': 'Lapa {0}',
        'calendar.BUTTON': 'Rādīt kalendāru',
        'datatable.sort.ASC': 'aktivizēt, lai kārtotu kolonnu augošā secībā',
        'datatable.sort.DESC': 'aktivizēt, lai kārtotu kolonnu dilstošā secībā',
        'columntoggler.CLOSE': 'Aizvērt',
        'overlaypanel.CLOSE': 'Aizvērt'
    },
    messages: { //optional for Client Side Validation
        'javax.faces.component.UIInput.REQUIRED': '{0}: Validācijas kļūda: nepieciešama vērtība.',
        'javax.faces.converter.IntegerConverter.INTEGER': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem.',
        'javax.faces.converter.IntegerConverter.INTEGER_detail': '{2}: \'{0}\' jābūt skaitlim no -2147483648 līdz 2147483647. Piemērs: {1}.',
        'javax.faces.converter.DoubleConverter.DOUBLE': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem.',
        'javax.faces.converter.DoubleConverter.DOUBLE_detail': '{2}: \'{0}\' jābūt skaitlim starp 4.9E-324 un 1.7976931348623157E308. Piemērs: {1}.',
        'javax.faces.converter.BigDecimalConverter.DECIMAL': '{2}: \'{0}\' jābūt decimāldaļskaitlim ar zīmi.',
        'javax.faces.converter.BigDecimalConverter.DECIMAL_detail': '{2}: \'{0}\' jābūt decimāldaļskaitlim ar zīmi, kas sastāv no nulles vai vairāk cipariem, aiz kura var būt komats un decimāldaļa. Piemērs: {1}.',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem.',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER_detail': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem. Piemērs: {1}.',
        'javax.faces.converter.ByteConverter.BYTE': '{2}: \'{0}\' jābūt skaitlim no 0 līdz 255.',
        'javax.faces.converter.ByteConverter.BYTE_detail': '{2}: \'{0}\' jābūt skaitlim no 0 līdz 255. Piemērs: {1}.',
        'javax.faces.converter.CharacterConverter.CHARACTER': '{1}: \'{0}\' jābūt derīgai rakstzīmei.',
        'javax.faces.converter.CharacterConverter.CHARACTER_detail': '{1}: \'{0}\' jābūt derīgai ASCII rakstzīmei.',
        'javax.faces.converter.ShortConverter.SHORT': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem.',
        'javax.faces.converter.ShortConverter.SHORT_detail': '{2}: \'{0}\' jābūt skaitlim no -32768 līdz 32767. Piemērs: {1}.',
        'javax.faces.converter.BooleanConverter.BOOLEAN': '{1}: \'{0}\' jābūt \'true\' vai \'false\'.',
        'javax.faces.converter.BooleanConverter.BOOLEAN_detail': '{1}: \'{0}\' jābūt \'true\' vai \'false\'. Jebkura vērtība, kas nav \'true\' tiks novērtēta kā \'false\'.',
        'javax.faces.validator.LongRangeValidator.MAXIMUM': '{1}: Validācijas kļūda: vērtība ir lielāka par pieļaujamo maksimālo vērtību \'{0}\'.',
        'javax.faces.validator.LongRangeValidator.MINIMUM': '{1}: Validācijas kļūda: vērtība ir mazāka par pieļaujamo minimālo vērtību \'{0}\'.',
        'javax.faces.validator.LongRangeValidator.NOT_IN_RANGE': '{2}: Validācijas kļūda: norādītais atribūts nav starp paredzētajām vērtībām {0} un {1}.',
        'javax.faces.validator.LongRangeValidator.TYPE={0}': 'Validācijas kļūda: vērtības tips nav pareizs.',
        'javax.faces.validator.DoubleRangeValidator.MAXIMUM': '{1}: Validācijas kļūda: vērtība ir lielāka par pieļaujamo maksimālo vērtību \'{0}\'.',
        'javax.faces.validator.DoubleRangeValidator.MINIMUM': '{1}: Validācijas kļūda: vērtība ir mazāka par pieļaujamo minimālo vērtību \'{0}\'.',
        'javax.faces.validator.DoubleRangeValidator.NOT_IN_RANGE': '{2}: Validācijas kļūda: norādītais atribūts nav starp paredzētajām vērtībām {0} un {1}.',
        'javax.faces.validator.DoubleRangeValidator.TYPE={0}': 'Validācijas kļūda: vērtības tips nav pareizs.',
        'javax.faces.converter.FloatConverter.FLOAT': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem.',
        'javax.faces.converter.FloatConverter.FLOAT_detail': '{2}: \'{0}\' jābūt skaitlim starp 1.4E-45 un 3.4028235E38. Piemērs: {1}.',
        'javax.faces.converter.DateTimeConverter.DATE': '{2}: \'{0}\' nevar saprast kā datumu.',
        'javax.faces.converter.DateTimeConverter.DATE_detail': '{2}: \'{0}\'nevar saprast kā datumu. Piemērs: {1}.',
        'javax.faces.converter.DateTimeConverter.TIME': '{2}: \'{0}\' nevar saprast kā laiku.',
        'javax.faces.converter.DateTimeConverter.TIME_detail': '{2}: \'{0}\' nevar saprast kā laiku. Piemērs: {1}.',
        'javax.faces.converter.DateTimeConverter.DATETIME': '{2}: \'{0}\' nevar saprast kā datumu un laiku.',
        'javax.faces.converter.DateTimeConverter.DATETIME_detail': '{2}: \'{0}\' nevar saprast kā datumu un laiku. Piemērs: {1}.',
        'javax.faces.converter.DateTimeConverter.PATTERN_TYPE': '{1}: Lai pārvērstu vērtību \'{0}\', ir jānorāda atribūts \'pattern\' vai \'type\'.',
        'javax.faces.converter.NumberConverter.CURRENCY': '{2}: \'{0}\' nevar saprast kā valūtas vērtību.',
        'javax.faces.converter.NumberConverter.CURRENCY_detail': '{2}: \'{0}\' nevar saprast kā valūtas vērtību. Piemērs: {1}.',
        'javax.faces.converter.NumberConverter.PERCENT': '{2}: \'{0}\' nevar saprast kā procentu.',
        'javax.faces.converter.NumberConverter.PERCENT_detail': '{2}: \'{0}\' nevar saprast kā procentu. Piemērs: {1}.',
        'javax.faces.converter.NumberConverter.NUMBER': '{2}: \'{0}\' nevar saprast kā skaitli.',
        'javax.faces.converter.NumberConverter.NUMBER_detail': '{2}: \'{0}\' nevar saprast kā skaitli. Piemērs: {1}.',
        'javax.faces.converter.NumberConverter.PATTERN': '{2}: \'{0}\' nevar saprast kā skaitļu modeli.',
        'javax.faces.converter.NumberConverter.PATTERN_detail': '{2}: \'{0}\' nevar saprast kā skaitļu modeli. Piemērs: {1}.',
        'javax.faces.validator.LengthValidator.MINIMUM': '{1}: Validācijas kļūda: garums ir mazāks par pieļaujamo minimālo vērtību \'{0}\'.',
        'javax.faces.validator.LengthValidator.MAXIMUM': '{1}: Validācijas kļūda: garums ir lielāks par pieļaujamo maksimālo vērtību \'{0}\'.',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET': 'Jāiestata regex modelis.',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET_detail': 'Ir jāiestata regex modelis uz vērtību, kas nav tukša.',
        'javax.faces.validator.RegexValidator.NOT_MATCHED': 'Regex modelis neatbilst.',
        'javax.faces.validator.RegexValidator.NOT_MATCHED_detail': 'Regex modelis \'{0}\' neatbilst.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION': 'Kļūda regulārajā izteiksmē.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION_detail': 'Kļūda regulārajā izteiksmē, \'{0}\'.',
        //optional for bean validation integration in client side validation
        'javax.faces.validator.BeanValidator.MESSAGE': '{0}',
        'javax.validation.constraints.AssertFalse.message': 'jābūt false.',
        'javax.validation.constraints.AssertTrue.message': 'jābūt true.',
        'javax.validation.constraints.DecimalMax.message': 'jābūt mazākam vai vienādam ar {0}.',
        'javax.validation.constraints.DecimalMin.message': 'jābūt lielākam vai vienādam ar {0}.',
        'javax.validation.constraints.Digits.message': 'skaitliskā vērtība ārpus robežām (paredzēts &lt;{0} cipari&gt;.&lt;{1} cipari&gt;).',
        'javax.validation.constraints.Future.message': 'jābūt nākotnē.',
        'javax.validation.constraints.Max.message': 'jābūt mazākam vai vienādam ar {0}.',
        'javax.validation.constraints.Min.message': 'jābūt lielākam vai vienādam ar {0}.',
        'javax.validation.constraints.NotNull.message': 'nedrīkst būt Null.',
        'javax.validation.constraints.Null.message': 'jābūt Null.',
        'javax.validation.constraints.Past.message': 'jābūt pagātnē.',
        'javax.validation.constraints.Pattern.message': 'jāatbilst "{0}".',
        'javax.validation.constraints.Size.message': 'lielumam jābūt starp {0} un {1}.'
    }
};

==> primefaces-13.0.0-RC1.jar: META-INF/resources/primefaces/locales/locale-lv.js <==
/** Latvian */
PrimeFaces.locales['lv'] = {
    closeText: 'Aizvērt',
    prevText: 'Iepriekšējais',
    nextText: 'Nākošais',
    monthNames: ['Janvāris', 'Februāris', 'Marts', 'Aprīlis', 'Maijs', 'Jūnijs', 'Jūlijs', 'Augusts', 'Septembris', 'Oktobris', 'Novembris', 'Decembris'],
    monthNamesShort: ['Jan', 'Feb', 'Mar', 'Apr', 'Mai', 'Jūn', 'Jūl', 'Aug', 'Sep', 'Okt', 'Nov', 'Dec'],
    dayNames: ['Svētdiena', 'Pirmdiena', 'Otrdiena', 'Trešdiena', 'Ceturtdiena', 'Piektdiena', 'Sestdiena'],
    dayNamesShort: ['Svē', 'Pirm', 'Otr', 'Tre', 'Cet', 'Pie', 'Ses'],
    dayNamesMin: ['Sv', 'P', 'O', 'T ', 'C', 'P ', 'S'],
    weekHeader: 'Nedēļa',
    firstDay: 1,
    isRTL: false,
    showMonthAfterYear: false,
    yearSuffix: '',
    timeOnlyTitle: 'Tikai laiks',
    timeText: 'Laiks',
    hourText: 'Stunda',
    minuteText: 'Minūte',
    secondText: 'Sekunde',
    millisecondText: 'Millisekunde',
    currentText: 'Šodiena',
    ampm: false,
    month: 'Mēnesis',
    week: 'Nedēļa',
    day: 'Diena',
    allDayText: 'Visa Diena',
    moreLinkText: 'Vairāk...',
    noEventsText: 'Nav notikumu',
    today: 'Šodiena',
    clear: 'Notīrīt',
    aria: {
        'paginator.PAGE': 'Lapa {0}',
        'calendar.BUTTON': 'Rādīt kalendāru',
        'datatable.sort.ASC': 'aktivizēt, lai kārtotu kolonnu augošā secībā',
        'datatable.sort.DESC': 'aktivizēt, lai kārtotu kolonnu dilstošā secībā',
        'columntoggler.CLOSE': 'Aizvērt',
        'overlaypanel.CLOSE': 'Aizvērt',
        'colorpicker.OPEN': 'Atvērt krāsu atlasītāju',
        'colorpicker.CLOSE': 'Aizvērt krāsu atlasītāju',
        'colorpicker.CLEAR': 'Notīrīt atlasīto krāsu',
        'colorpicker.MARKER': 'Piesātinājums: {s}. Spilgtums: {v}.',
        'colorpicker.HUESLIDER': 'Krāsu toņa slīdnis',
        'colorpicker.ALPHASLIDER': 'Necaurspīdības slīdnis',
        'colorpicker.INPUT': 'Krāsas vērtības lauks',
        'colorpicker.FORMAT': 'Krāsu formāts',
        'colorpicker.SWATCH': 'Krāsu palete',
        'colorpicker.INSTRUCTION': 'Piesātinājuma un spilgtuma atlasītājs. Lai atlasītu, izmantojiet augšup, lejup, pa kreisi un pa labi vērsto bulttaustiņu.'
    },
    messages: { //optional for Client Side Validation
        'javax.faces.component.UIInput.REQUIRED': '{0}: Validācijas kļūda: nepieciešama vērtība.',
        'javax.faces.converter.IntegerConverter.INTEGER': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem.',
        'javax.faces.converter.IntegerConverter.INTEGER_detail': '{2}: \'{0}\' jābūt skaitlim no -2147483648 līdz 2147483647. Piemērs: {1}.',
        'javax.faces.converter.DoubleConverter.DOUBLE': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem.',
        'javax.faces.converter.DoubleConverter.DOUBLE_detail': '{2}: \'{0}\' jābūt skaitlim starp 4.9E-324 un 1.7976931348623157E308. Piemērs: {1}.',
        'javax.faces.converter.BigDecimalConverter.DECIMAL': '{2}: \'{0}\' jābūt decimāldaļskaitlim ar zīmi.',
        'javax.faces.converter.BigDecimalConverter.DECIMAL_detail': '{2}: \'{0}\' jābūt decimāldaļskaitlim ar zīmi, kas sastāv no nulles vai vairāk cipariem, aiz kura var būt komats un decimāldaļa. Piemērs: {1}.',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem.',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER_detail': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem. Piemērs: {1}.',
        'javax.faces.converter.ByteConverter.BYTE': '{2}: \'{0}\' jābūt skaitlim no 0 līdz 255.',
        'javax.faces.converter.ByteConverter.BYTE_detail': '{2}: \'{0}\' jābūt skaitlim no 0 līdz 255. Piemērs: {1}.',
        'javax.faces.converter.CharacterConverter.CHARACTER': '{1}: \'{0}\' jābūt derīgai rakstzīmei.',
        'javax.faces.converter.CharacterConverter.CHARACTER_detail': '{1}: \'{0}\' jābūt derīgai ASCII rakstzīmei.',
        'javax.faces.converter.ShortConverter.SHORT': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem.',
        'javax.faces.converter.ShortConverter.SHORT_detail': '{2}: \'{0}\' jābūt skaitlim no -32768 līdz 32767. Piemērs: {1}.',
        'javax.faces.converter.BooleanConverter.BOOLEAN': '{1}: \'{0}\' jābūt \'true\' vai \'false\'.',
        'javax.faces.converter.BooleanConverter.BOOLEAN_detail': '{1}: \'{0}\' jābūt \'true\' vai \'false\'. Jebkura vērtība, kas nav \'true\' tiks novērtēta kā \'false\'.',
        'javax.faces.validator.LongRangeValidator.MAXIMUM': '{1}: Validācijas kļūda: vērtība ir lielāka par pieļaujamo maksimālo vērtību \'{0}\'.',
        'javax.faces.validator.LongRangeValidator.MINIMUM': '{1}: Validācijas kļūda: vērtība ir mazāka par pieļaujamo minimālo vērtību \'{0}\'.',
        'javax.faces.validator.LongRangeValidator.NOT_IN_RANGE': '{2}: Validācijas kļūda: norādītais atribūts nav starp paredzētajām vērtībām {0} un {1}.',
        'javax.faces.validator.LongRangeValidator.TYPE': '{0}: Validācijas kļūda: vērtības tips nav pareizs.',
        'javax.faces.validator.DoubleRangeValidator.MAXIMUM': '{1}: Validācijas kļūda: vērtība ir lielāka par pieļaujamo maksimālo vērtību \'{0}\'.',
        'javax.faces.validator.DoubleRangeValidator.MINIMUM': '{1}: Validācijas kļūda: vērtība ir mazāka par pieļaujamo minimālo vērtību \'{0}\'.',
        'javax.faces.validator.DoubleRangeValidator.NOT_IN_RANGE': '{2}: Validācijas kļūda: norādītais atribūts nav starp paredzētajām vērtībām {0} un {1}.',
        'javax.faces.validator.DoubleRangeValidator.TYPE': '{0}: Validācijas kļūda: vērtības tips nav pareizs.',
        'javax.faces.converter.FloatConverter.FLOAT': '{2}: \'{0}\' jābūt skaitlim, kas sastāv no viena vai vairākiem cipariem.',
        'javax.faces.converter.FloatConverter.FLOAT_detail': '{2}: \'{0}\' jābūt skaitlim starp 1.4E-45 un 3.4028235E38. Piemērs: {1}.',
        'javax.faces.converter.DateTimeConverter.DATE': '{2}: \'{0}\' nevar saprast kā datumu.',
        'javax.faces.converter.DateTimeConverter.DATE_detail': '{2}: \'{0}\'nevar saprast kā datumu. Piemērs: {1}.',
        'javax.faces.converter.DateTimeConverter.TIME': '{2}: \'{0}\' nevar saprast kā laiku.',
        'javax.faces.converter.DateTimeConverter.TIME_detail': '{2}: \'{0}\' nevar saprast kā laiku. Piemērs: {1}.',
        'javax.faces.converter.DateTimeConverter.DATETIME': '{2}: \'{0}\' nevar saprast kā datumu un laiku.',
        'javax.faces.converter.DateTimeConverter.DATETIME_detail': '{2}: \'{0}\' nevar saprast kā datumu un laiku. Piemērs: {1}.',
        'javax.faces.converter.DateTimeConverter.PATTERN_TYPE': '{1}: Lai pārvērstu vērtību \'{0}\', ir jānorāda atribūts \'pattern\' vai \'type\'.',
        'javax.faces.converter.NumberConverter.CURRENCY': '{2}: \'{0}\' nevar saprast kā valūtas vērtību.',
        'javax.faces.converter.NumberConverter.CURRENCY_detail': '{2}: \'{0}\' nevar saprast kā valūtas vērtību. Piemērs: {1}.',
        'javax.faces.converter.NumberConverter.PERCENT': '{2}: \'{0}\' nevar saprast kā procentu.',
        'javax.faces.converter.NumberConverter.PERCENT_detail': '{2}: \'{0}\' nevar saprast kā procentu. Piemērs: {1}.',
        'javax.faces.converter.NumberConverter.NUMBER': '{2}: \'{0}\' nevar saprast kā skaitli.',
        'javax.faces.converter.NumberConverter.NUMBER_detail': '{2}: \'{0}\' nevar saprast kā skaitli. Piemērs: {1}.',
        'javax.faces.converter.NumberConverter.PATTERN': '{2}: \'{0}\' nevar saprast kā skaitļu modeli.',
        'javax.faces.converter.NumberConverter.PATTERN_detail': '{2}: \'{0}\' nevar saprast kā skaitļu modeli. Piemērs: {1}.',
        'javax.faces.validator.LengthValidator.MINIMUM': '{1}: Validācijas kļūda: garums ir mazāks par pieļaujamo minimālo vērtību \'{0}\'.',
        'javax.faces.validator.LengthValidator.MAXIMUM': '{1}: Validācijas kļūda: garums ir lielāks par pieļaujamo maksimālo vērtību \'{0}\'.',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET': 'Jāiestata regex modelis.',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET_detail': 'Ir jāiestata regex modelis uz vērtību, kas nav tukša.',
        'javax.faces.validator.RegexValidator.NOT_MATCHED': 'Regex modelis neatbilst.',
        'javax.faces.validator.RegexValidator.NOT_MATCHED_detail': 'Regex modelis \'{0}\' neatbilst.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION': 'Kļūda regulārajā izteiksmē.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION_detail': 'Kļūda regulārajā izteiksmē, \'{0}\'.',
        //optional for bean validation integration in client side validation
        'javax.faces.validator.BeanValidator.MESSAGE': '{0}',
        'javax.validation.constraints.AssertFalse.message': 'jābūt false.',
        'javax.validation.constraints.AssertTrue.message': 'jābūt true.',
        'javax.validation.constraints.DecimalMax.message': 'jābūt mazākam vai vienādam ar {0}.',
        'javax.validation.constraints.DecimalMin.message': 'jābūt lielākam vai vienādam ar {0}.',
        'javax.validation.constraints.Digits.message': 'skaitliskā vērtība ārpus robežām (paredzēts &lt;{0} cipari&gt;.&lt;{1} cipari&gt;).',
        'javax.validation.constraints.Future.message': 'jābūt nākotnē.',
        'javax.validation.constraints.Max.message': 'jābūt mazākam vai vienādam ar {0}.',
        'javax.validation.constraints.Min.message': 'jābūt lielākam vai vienādam ar {0}.',
        'javax.validation.constraints.NotNull.message': 'nedrīkst būt Null.',
        'javax.validation.constraints.Null.message': 'jābūt Null.',
        'javax.validation.constraints.Past.message': 'jābūt pagātnē.',
        'javax.validation.constraints.Pattern.message': 'jāatbilst "{0}".',
        'javax.validation.constraints.Size.message': 'lielumam jābūt starp {0} un {1}.'
    }
};
